"""
Author: Michel Peltriaux
Organization: Struktur- und Genehmigungsdirektion Nord, Rhineland-Palatinate, Germany
Contact: michel.peltriaux@sgdnord.rlp.de
Created on: 17.08.21

"""
from django.contrib.auth.models import User
from simple_sso.sso_client.client import Client


class KonovaSSOClient(Client):
    """ Konova specialized derivate of general sso.Client.

    Adds some custom behaviour for konova usage.

    """
    def build_user(self, user_data):
        """ Creates a user or updates user data

        Args:
            user_data ():

        Returns:

        """
        try:
            user = User.objects.get(username=user_data['username'])
            # Update user data, excluding some changes
            skipable_attrs = {
                "username",
                "is_staff",
                "is_superuser",
            }
            for _attr, _val in user_data.items():
                if _attr in skipable_attrs:
                    continue
                setattr(user, _attr, _val)
        except User.DoesNotExist:
            user = User(**user_data)
        user.set_unusable_password()
        user.save()
        return user